@@ -282,6 +282,11 @@ new_file_response_cb (GtkWidget *w,
 		return;
 	}
 
+	if (response == GTK_RESPONSE_HELP) {
+		show_help_dialog (GTK_WINDOW (file_sel), "file-roller-create");
+		return;
+	}
+
 	window = g_object_get_data (G_OBJECT (file_sel), "fr_window");
 
 	path = get_archive_filename_from_selector (window, file_sel);
@@ -345,6 +350,7 @@ activate_action_new (GtkAction *action,
 			GTK_FILE_CHOOSER_ACTION_SAVE,
 			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 			GTK_STOCK_NEW, GTK_RESPONSE_OK,
+			GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 			NULL);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (file_sel), GTK_RESPONSE_OK);
@@ -541,6 +547,11 @@ save_file_response_cb (GtkWidget *w,
 		return;
 	}
 
+	if (response == GTK_RESPONSE_HELP) {
+		show_help_dialog (GTK_WINDOW (file_sel), "file-roller-convert-archive");
+		return;
+	}
+
 	window = g_object_get_data (G_OBJECT (file_sel), "fr_window");
 
 	path = get_archive_filename_from_selector (window, file_sel);
@@ -569,6 +580,7 @@ activate_action_save_as (GtkAction *action,
 			GTK_FILE_CHOOSER_ACTION_SAVE,
 			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 			GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+			GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 			NULL);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (file_sel), GTK_RESPONSE_OK);
@@ -875,46 +887,47 @@ activate_action_about (GtkAction *action,
 		       gpointer   data)
 {
 	FRWindow         *window = data;
-	static GtkWidget *about = NULL;
+	
+	char *license_text;
+
 	const char       *authors[] = {
 		"Paolo Bacchilega <paolo.bacchilega@libero.it>", NULL
 	};
+
 	const char       *documenters [] = {
 		"Alexander Kirillov", 
 		"Breda McColgan",
 		NULL
 	};
-	const char       *translator_credits = _("translator-credits");
+	
+	const char *license[] = {
+		"File Roller is free software; you can redistribute it and/or modify "
+		"it under the terms of the GNU General Public License as published by "
+		"the Free Software Foundation; either version 2 of the License, or "
+		"(at your option) any later version.",
+		"File Roller is distributed in the hope that it will be useful, "
+		"but WITHOUT ANY WARRANTY; without even the implied warranty of "
+		"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
+		"GNU General Public License for more details.",
+		"You should have received a copy of the GNU General Public License "
+		"along with Nautilus; if not, write to the Free Software Foundation, Inc., "
+		"51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA"
+	};
 
+	license_text = g_strconcat (license[0], "\n\n", license[1], "\n\n",
+				    license[2], "\n\n", NULL);
 
-	if (about != NULL) {
-		gtk_window_present (GTK_WINDOW (about));
-		return;
-	}
+	gtk_show_about_dialog (GTK_WINDOW (window->app),
+			       "version", VERSION,
+			       "copyright", "Copyright \xc2\xa9 2001-2006 Free Software Foundation, Inc.",
+			       "comments", _("An archive manager for GNOME."),
+			       "authors", authors,
+			       "documenters", documenters,
+			       "translator-credits", _("translator-credits"),
+			       "logo-icon-name", "file-roller",
+			       "license", license_text,
+			       "wrap-license", TRUE,
+			       NULL);
 
-	about = gtk_about_dialog_new ();
-	g_object_set (about,
-		      "name",  _("File Roller"),
-		      "version", VERSION,
-		      "copyright", "Copyright \xc2\xa9 2001-2005 Free Software Foundation, Inc.",
-		      "comments", _("An archive manager for GNOME."),
-		      "authors", authors,
-		      "documenters", documenters,
-		      "translator_credits", strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
-		      "logo_icon_name", "file-roller",
-		      "website", NULL,
-		      "website_label", NULL,
-		      "license", NULL,
-		      NULL);
-
-	gtk_window_set_destroy_with_parent (GTK_WINDOW (about), TRUE);
-	gtk_window_set_transient_for (GTK_WINDOW (about), 
-				      GTK_WINDOW (window->app));
-
-	g_signal_connect (G_OBJECT (about), 
-			  "destroy",
-			  G_CALLBACK (gtk_widget_destroyed), 
-			  &about);
-
-	gtk_widget_show (about);
+	g_free (license_text);
 }
