@@ -38,19 +38,22 @@ typedef struct _FRCommand       FRCommand;
 typedef struct _FRCommandClass  FRCommandClass;
 
 typedef enum {
+	FR_ACTION_NONE,
 	FR_ACTION_LIST,
 	FR_ACTION_ADD,
 	FR_ACTION_DELETE,
 	FR_ACTION_EXTRACT,
 	FR_ACTION_TEST,
-	FR_ACTION_GET_LIST
+	FR_ACTION_GET_LIST,
+	FR_ACTION_SAVE
 } FRAction;
 
 struct _FRCommand
 {
         GObject  __parent;
 
-	GList * file_list;       /* FileData elements */
+	FRFileType  file_type;
+	GList      *file_list;       /* FileData elements */
 
 	/*<protected>*/
 
@@ -89,7 +92,8 @@ struct _FRCommandClass
 
 	/*<virtual functions>*/
 
-	void        (*list)           (FRCommand     *comm);
+	void        (*list)           (FRCommand     *comm,
+				       const char    *password);
 
 	void        (*add)            (FRCommand     *comm,
 				       GList         *file_list,
@@ -148,7 +152,8 @@ void           fr_command_construct          (FRCommand     *comm,
 void           fr_command_set_filename       (FRCommand     *comm,
 					      const char    *filename);
 
-void           fr_command_list               (FRCommand     *comm);
+void           fr_command_list               (FRCommand     *comm,
+					      const char    *password);
 
 void           fr_command_add                (FRCommand     *comm,
 					      GList         *file_list,
